macro_rules! test_workspace {
($label:expr) => { ... };
}Expand description
Create a TestWorkspace whose fixture root is <caller>/tests/fixtures.
The caller manifest directory is captured at macro expansion time,
so this can be used from any crate that depends on rskit-testutil.